import pyautogui
import time
import logging

class spamBot:
    def __init__(self, message, interval):
        self.message = message
        self.interval = interval
        logging.info("SpamBot initialized!! Put the cursor on the chat box and wait for 5 seconds.")

    def spam(self):
        time.sleep(5)
        message = self.message
        n = 0
        interval = self.interval
        while n!=interval:
            pyautogui.typewrite(self.message)
            pyautogui.press("enter")
            n = n+1
            # if a key is pressed, stop the spam
            if pyautogui.keyDown("ctrl"):
                logging.info("SpamBot stopped!!")
                break
    
    def spamForever(self):
        logging.info("SpamBot started!!")
        while True:
            self.spam()
            # if a key is pressed, stop the spam
            if pyautogui.keyDown("ctrl"):
                logging.info("SpamBot stopped!!")
                break
    
    def spamForeverWithDelay(self, delay):
        logging.info("SpamBot started!!")
        while True:
            self.spam()
            time.sleep(delay)
            # if a key is pressed, stop the spam
            if pyautogui.keyDown("ctrl"):
                logging.info("SpamBot stopped!!")
                break

            


from distutils.core import setup
setup(
  name = 'spamBot101',
  packages = ['spamBot101'],
  version = '0.1',
  license='MIT',
  description = 'A simple spam bot for WhatsApp. It can spam a message a given number of times or spam forever. It can be stopped by pressing ctrl.',
  author = 'Sushil Dhakal',
  author_email = 'sushilldhakal25@gmail.com',
  url = 'https://github.com/sushil3125/Spam-Bot-using-Python',
  download_url = 'https://github.com/sushil3125/Spam-Bot-using-Python/blob/main/projectSpamBot.exe',
  install_requires=[
          'pyautogui'
      ],
  classifiers=[ 
    # Specify the Python versions you support here. In particular, ensure
    # that you indicate whether you support Python 2, Python 3 or both.
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)